@@ -23,14 +23,14 @@ this module will be included in the api
     (A cube with 1 channel is a continuum image (nterms=1))
 '''
 
-def make_pb(img_dataset,pb_parms, grid_parms, sel_parms, storage_parms):
+def make_pb(img_xds,pb_parms, grid_parms, sel_parms):
     """
     The make_pb function currently supports rotationally symmetric airy disk primary beams. Primary beams can be generated for any number of dishes.
     The make_pb_parms['list_dish_diameters'] and make_pb_parms['list_blockage_diameters'] must be specified for each dish.
     
     Parameters
     ----------
-    img_dataset : xarray.core.dataset.Dataset
+    img_xds : xarray.core.dataset.Dataset
         Input image dataset.
     pb_parms : dictionary
     pb_parms['list_dish_diameters'] : list of number
@@ -51,29 +51,11 @@ def make_pb(img_dataset,pb_parms, grid_parms, sel_parms, storage_parms):
     sel_parms : dictionary
     sel_parms['pb'] = 'PB'
         The created PB name.
-    storage_parms : dictionary
-    storage_parms['to_disk'] : bool, default = False
-        If true the dask graph is executed and saved to disk in the zarr format.
-    storage_parms['append'] : bool, default = False
-        If storage_parms['to_disk'] is True only the dask graph associated with the function is executed and the resulting data variables are saved to an existing zarr file on disk.
-        Note that graphs on unrelated data to this function will not be executed or saved.
-    storage_parms['outfile'] : str
-        The zarr file to create or append to.
-    storage_parms['chunks_on_disk'] : dict of int, default = {}
-        The chunk size to use when writing to disk. This is ignored if storage_parms['append'] is True. The default will use the chunking of the input dataset.
-    storage_parms['chunks_return'] : dict of int, default = {}
-        The chunk size of the dataset that is returned. The default will use the chunking of the input dataset.
-    storage_parms['graph_name'] : str
-        The time to compute and save the data is stored in the attribute section of the dataset and storage_parms['graph_name'] is used in the label.
-    storage_parms['compressor'] : numcodecs.blosc.Blosc,default=Blosc(cname='zstd', clevel=2, shuffle=0)
-        The compression algorithm to use. Available compression algorithms can be found at https://numcodecs.readthedocs.io/en/stable/blosc.html.
-    
     Returns
     -------
     img_xds : xarray.core.dataset.Dataset
     """
-    from ngcasa._ngcasa_utils._store import _store
-    from ngcasa._ngcasa_utils._check_parms import _check_storage_parms, _check_sel_parms
+    from cngi._utils._check_parms import _check_sel_parms, _check_existence_sel_parms
     from ._imaging_utils._check_imaging_parms import _check_pb_parms, _check_grid_parms
     import numpy as np
     import dask.array as da
@@ -81,14 +63,18 @@ def make_pb(img_dataset,pb_parms, grid_parms, sel_parms, storage_parms):
     import xarray as xr
     import matplotlib.pylab as plt
     
+    print('######################### Start make_pb #########################')
+    
+    _img_xds = img_xds.copy(deep=True)
     _grid_parms = copy.deepcopy(grid_parms)
     _pb_parms =  copy.deepcopy(pb_parms)
-    _storage_parms = copy.deepcopy(storage_parms)
     _sel_parms = copy.deepcopy(sel_parms)
     
-    assert(_check_sel_parms(_sel_parms,{'pb':'PB'})), "######### ERROR: sel_parms checking failed"
-    assert(_check_pb_parms(img_dataset,_pb_parms)), "######### ERROR: user_imaging_weights_parms checking failed"
-    assert(_check_storage_parms(_storage_parms,'dataset.img.zarr','make_pb')), "######### ERROR: user_storage_parms checking failed"
+    
+    #Check img data_group
+    _check_sel_parms(_img_xds,_sel_parms,new_or_modified_data_variables={'pb':'PB'},append_to_in_id=True)
+    
+    assert(_check_pb_parms(_img_xds,_pb_parms)), "######### ERROR: user_imaging_weights_parms checking failed"
     assert(_check_grid_parms(_grid_parms)), "######### ERROR: grid_parms checking failed"
     
     #parameter check
@@ -107,24 +93,25 @@ def make_pb(img_dataset,pb_parms, grid_parms, sel_parms, storage_parms):
     _pb_parms['center_indx'] = []
 
 
-    chan_chunk_size = img_dataset.chan_width.chunks[0][0]
-    freq_coords = da.from_array(img_dataset.coords['chan'].values, chunks=(chan_chunk_size))
+    chan_chunk_size = _img_xds.chan_width.chunks[0][0]
+    freq_coords = da.from_array(_img_xds.coords['chan'].values, chunks=(chan_chunk_size))
     
-    pol = img_dataset.pol.values #don't want chunking here
+    pol = _img_xds.pol.values #don't want chunking here
 
     chunksize = (_grid_parms['image_size'][0],_grid_parms['image_size'][1]) + freq_coords.chunksize + (len(pol),) + (len(_pb_parms['list_dish_diameters']),)
     
     pb = da.map_blocks(pb_func, freq_coords, pol, _pb_parms, _grid_parms, chunks=chunksize ,new_axis=[0,1,3,4], dtype=np.double)
     
-    ## Add PB to img_dataset
-    '''
-    coords = {'d0': np.arange(pb_parms['imsize'][0]), 'd1': np.arange(_pb_parms['imsize'][1]),
-              'chan': freq_coords.compute(), 'pol': pol,'dish_type': np.arange(len(_pb_parms['list_dish_diameters']))}
-    '''
+    ## Add PB to img_xds
     
-    img_dataset[_pb_parms['pb_name']] = xr.DataArray(pb, dims=['d0', 'd1', 'chan', 'pol','dish_type'])
-    img_dataset = img_dataset.assign_coords({'dish_type': np.arange(len(_pb_parms['list_dish_diameters']))})
+#    coords = {'d0': np.arange(pb_parms['imsize'][0]), 'd1': np.arange(_pb_parms['imsize'][1]),
+#              'chan': freq_coords.compute(), 'pol': pol,'dish_type': np.arange(len(_pb_parms['list_dish_diameters']))}
     
-    list_xarray_data_variables = [img_dataset[_pb_parms['pb_name']]]
-    return _store(img_dataset,list_xarray_data_variables,_storage_parms)
+    
+    _img_xds[_sel_parms['data_group_out']['pb']] = xr.DataArray(pb[:,:,None,:,:,:], dims=['l', 'm', 'time', 'chan', 'pol','dish_type'])
+    _img_xds = _img_xds.assign_coords({'dish_type': np.arange(len(_pb_parms['list_dish_diameters']))})
+    _img_xds.attrs['data_groups'][0] = {**_img_xds.attrs['data_groups'][0],**{_sel_parms['data_group_out']['id']:_sel_parms['data_group_out']}}
+    
+    print('######################### Created graph for make_pb #########################')
+    return _img_xds
     
